# Installation

## Voraussetzungen

- Python 3.10 oder höher

## Setup

```bash
uv add seven2one-questra-automation
```

## Dependencies

- `gql` - GraphQL Client
- `loguru` - Logging
- `requests-toolbelt` - HTTP Utilities
- `seven2one-questra-authentication` - Authentifizierung
